# Script to generate plots with EDX maps for the ESAFORM2024 paper:
#
#           Polymer-Metal Interactions and Their Effect on
#                Tool-Ply Friction of C/PEKK in Melt
#              Grouve et al. (w.j.b.grouve@utwente.nl)
#
import matplotlib.pyplot as plt
import numpy as np
import scienceplots

folder = "../microscopy/EDX_APC_fracture_surface/"

#
# Plot EDX map for overview image
# -------------------------------
fn = "EDX_Fe_APC_overview.csv"
data = np.genfromtxt(fn, delimiter=",")[:, :-1]

with plt.style.context(['science', 'nature', 'no-latex', 'bright']):
    fig, ax = plt.subplots(1, 1, figsize=(2, 2))
    ax.imshow(data, cmap='inferno', vmin=1.0, vmax=6.0)
    ax.axis('off')
    # plt.savefig(folder+"EDX_Fe_APC_overview.png", dpi=600)
    plt.show(block=False)

#
# Plot EDX map for zoomed image with particle
# -------------------------------------------
fn = "EDX_Fe_APC_particle.csv"
data = np.genfromtxt(fn, delimiter=",")[:, :-1]

with plt.style.context(['science', 'nature', 'no-latex', 'bright']):
    fig, ax = plt.subplots(1, 1, figsize=(2, 2))
    ax.imshow(data, cmap='inferno', vmin=1.0, vmax=8.0)
    ax.axis('off')
    # plt.savefig(folder+"EDX_Fe_APC_particle.png", dpi=600)
    plt.show(block=False)
